import { RequestConfig } from './request';
export interface IdsConfig {
    endpoint: string;
    accessKeyId: string;
    accessKeySecret: string;
}
export declare enum IdsChannel {
    Csdn = 1,
    Wechat = 2,
    Zhihu = 3,
    Juejin = 4
}
export declare type IdsCrawlRule = 'fulldata' | 'extdata';
export interface IdsArticle {
    code: IdsChannel;
    author_id: string | number;
    cover_url?: string;
    title: string;
    author_name?: string;
    sn_code: string;
    original_url?: string;
    source_address: string;
    is_headline?: 0 | 1;
    is_original: 0 | 1;
    body: string;
    label?: string;
    published_at: Date;
    external_read_num?: number;
    external_see_num?: number;
    external_like_num?: number;
    external_comment_num?: number;
}
export declare enum IdsSource {
    Manual = 0,
    User = 1,
    AliyunMarket = 2,
    TencentCloudMarket = 3,
    HuaweiCloudMarket = 4,
    Xiniu = 6,
    Website = 7
}
export interface IdsProvider {
    name: string;
    short_name?: string;
    tel?: string;
    email?: string;
    logo?: string;
    description?: string;
    service_time?: string;
    source: IdsSource;
    source_pid: string | number;
    source_url?: string;
}
export interface IdsSolutionExtra {
    api_gateway: {
        service_id: string;
        api_id: string;
        dep_api_id?: string[];
    };
    icon_padding?: number;
}
export interface IdsSolution {
    uid: number;
    title: string;
    description: string;
    images: string;
    details: string;
    plain_text?: string;
    service_type?: string[];
    dimension: 1 | 2;
    status: number;
    source: IdsSource;
    source_id: string;
    source_pid: string;
    source_dt?: string;
    source_url: string;
    source_tags?: string[];
    source_labels?: string;
    ext_sold?: number;
    ext_score?: number;
    skus?: any[];
    api?: any[];
    doc_path?: string;
    is_signed?: 1 | 0;
    type?: 'gateway';
    min_price?: number;
    max_price?: number;
    extra?: IdsSolutionExtra | string;
}
export interface IdsUser {
    uid?: string;
    password: string;
    mobile?: string;
    email?: string;
    nickname: string;
    introduction?: string;
    icon_url?: string;
    source: string;
}
export interface IdsLogin {
    open_type?: string;
    weixin_code?: string;
    weibo_token?: string;
    login_name?: string;
    email?: string;
    mobile?: string;
    password?: string;
    captcha?: string;
    client_id?: string;
    xAPP?: string;
    xVersion?: string;
}
export declare const randomtail: () => string;
export declare class Ids {
    config: IdsConfig;
    constructor(config: IdsConfig);
    request(config: RequestConfig): Promise<any>;
    getCrawlAuthors(channel: IdsChannel): Promise<any>;
    getCrawlArticleRules(params: {
        ids: string[];
        channel: IdsChannel;
    }): Promise<any>;
    putArticle(data: IdsArticle, rule: IdsCrawlRule): Promise<any>;
    putProvider(data: IdsProvider, config?: RequestConfig): Promise<any>;
    putSolution(data: IdsSolution, config?: RequestConfig): Promise<any>;
    createUser(data: IdsUser, config?: RequestConfig): Promise<any>;
    login(data: IdsLogin, config?: RequestConfig): Promise<any>;
}
